@@ -3,6 +3,7 @@
 import logging
 from typing import Dict, Type, Union
 
+import sentencepiece as _sentencepiece
 import pytorch_lightning as pl
 import torch.optim as optim
 from torch import Tensor
@@ -19,6 +20,9 @@ from transformers import (
     XLNetLMHeadModel,
 )
 
+# sentencepiece has to be loaded before lightning to avoid segfaults
+_sentencepiece
+
 logger = logging.getLogger(__name__)
 logger.addHandler(logging.NullHandler())
 
